@@ -86,7 +86,7 @@ class Exceptions:
 
 class SSOAdminClient:
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/sso-admin.html#SSOAdmin.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/sso-admin.html#SSOAdmin.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client.html)
     """
 
@@ -97,13 +97,13 @@ class SSOAdminClient:
         self, *, InstanceArn: str, PermissionSetArn: str, ManagedPolicyArn: str
     ) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/sso-admin.html#SSOAdmin.Client.attach_managed_policy_to_permission_set)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/sso-admin.html#SSOAdmin.Client.attach_managed_policy_to_permission_set)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client.html#attach_managed_policy_to_permission_set)
         """
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/sso-admin.html#SSOAdmin.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/sso-admin.html#SSOAdmin.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client.html#can_paginate)
         """
 
@@ -118,17 +118,18 @@ class SSOAdminClient:
         PrincipalId: str
     ) -> CreateAccountAssignmentResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/sso-admin.html#SSOAdmin.Client.create_account_assignment)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/sso-admin.html#SSOAdmin.Client.create_account_assignment)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client.html#create_account_assignment)
         """
 
     def create_instance_access_control_attribute_configuration(
         self,
+        *,
         InstanceArn: str,
-        InstanceAccessControlAttributeConfiguration: "InstanceAccessControlAttributeConfigurationTypeDef",
+        InstanceAccessControlAttributeConfiguration: "InstanceAccessControlAttributeConfigurationTypeDef"
     ) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/sso-admin.html#SSOAdmin.Client.create_instance_access_control_attribute_configuration)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/sso-admin.html#SSOAdmin.Client.create_instance_access_control_attribute_configuration)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client.html#create_instance_access_control_attribute_configuration)
         """
 
@@ -143,7 +144,7 @@ class SSOAdminClient:
         Tags: List["TagTypeDef"] = None
     ) -> CreatePermissionSetResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/sso-admin.html#SSOAdmin.Client.create_permission_set)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/sso-admin.html#SSOAdmin.Client.create_permission_set)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client.html#create_permission_set)
         """
 
@@ -158,69 +159,69 @@ class SSOAdminClient:
         PrincipalId: str
     ) -> DeleteAccountAssignmentResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/sso-admin.html#SSOAdmin.Client.delete_account_assignment)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/sso-admin.html#SSOAdmin.Client.delete_account_assignment)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client.html#delete_account_assignment)
         """
 
     def delete_inline_policy_from_permission_set(
-        self, InstanceArn: str, PermissionSetArn: str
+        self, *, InstanceArn: str, PermissionSetArn: str
     ) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/sso-admin.html#SSOAdmin.Client.delete_inline_policy_from_permission_set)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/sso-admin.html#SSOAdmin.Client.delete_inline_policy_from_permission_set)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client.html#delete_inline_policy_from_permission_set)
         """
 
     def delete_instance_access_control_attribute_configuration(
-        self, InstanceArn: str
+        self, *, InstanceArn: str
     ) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/sso-admin.html#SSOAdmin.Client.delete_instance_access_control_attribute_configuration)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/sso-admin.html#SSOAdmin.Client.delete_instance_access_control_attribute_configuration)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client.html#delete_instance_access_control_attribute_configuration)
         """
 
-    def delete_permission_set(self, InstanceArn: str, PermissionSetArn: str) -> Dict[str, Any]:
+    def delete_permission_set(self, *, InstanceArn: str, PermissionSetArn: str) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/sso-admin.html#SSOAdmin.Client.delete_permission_set)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/sso-admin.html#SSOAdmin.Client.delete_permission_set)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client.html#delete_permission_set)
         """
 
     def describe_account_assignment_creation_status(
-        self, InstanceArn: str, AccountAssignmentCreationRequestId: str
+        self, *, InstanceArn: str, AccountAssignmentCreationRequestId: str
     ) -> DescribeAccountAssignmentCreationStatusResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/sso-admin.html#SSOAdmin.Client.describe_account_assignment_creation_status)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/sso-admin.html#SSOAdmin.Client.describe_account_assignment_creation_status)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client.html#describe_account_assignment_creation_status)
         """
 
     def describe_account_assignment_deletion_status(
-        self, InstanceArn: str, AccountAssignmentDeletionRequestId: str
+        self, *, InstanceArn: str, AccountAssignmentDeletionRequestId: str
     ) -> DescribeAccountAssignmentDeletionStatusResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/sso-admin.html#SSOAdmin.Client.describe_account_assignment_deletion_status)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/sso-admin.html#SSOAdmin.Client.describe_account_assignment_deletion_status)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client.html#describe_account_assignment_deletion_status)
         """
 
     def describe_instance_access_control_attribute_configuration(
-        self, InstanceArn: str
+        self, *, InstanceArn: str
     ) -> DescribeInstanceAccessControlAttributeConfigurationResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/sso-admin.html#SSOAdmin.Client.describe_instance_access_control_attribute_configuration)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/sso-admin.html#SSOAdmin.Client.describe_instance_access_control_attribute_configuration)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client.html#describe_instance_access_control_attribute_configuration)
         """
 
     def describe_permission_set(
-        self, InstanceArn: str, PermissionSetArn: str
+        self, *, InstanceArn: str, PermissionSetArn: str
     ) -> DescribePermissionSetResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/sso-admin.html#SSOAdmin.Client.describe_permission_set)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/sso-admin.html#SSOAdmin.Client.describe_permission_set)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client.html#describe_permission_set)
         """
 
     def describe_permission_set_provisioning_status(
-        self, InstanceArn: str, ProvisionPermissionSetRequestId: str
+        self, *, InstanceArn: str, ProvisionPermissionSetRequestId: str
     ) -> DescribePermissionSetProvisioningStatusResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/sso-admin.html#SSOAdmin.Client.describe_permission_set_provisioning_status)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/sso-admin.html#SSOAdmin.Client.describe_permission_set_provisioning_status)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client.html#describe_permission_set_provisioning_status)
         """
 
@@ -228,7 +229,7 @@ class SSOAdminClient:
         self, *, InstanceArn: str, PermissionSetArn: str, ManagedPolicyArn: str
     ) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/sso-admin.html#SSOAdmin.Client.detach_managed_policy_from_permission_set)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/sso-admin.html#SSOAdmin.Client.detach_managed_policy_from_permission_set)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client.html#detach_managed_policy_from_permission_set)
         """
 
@@ -240,15 +241,15 @@ class SSOAdminClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/sso-admin.html#SSOAdmin.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/sso-admin.html#SSOAdmin.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client.html#generate_presigned_url)
         """
 
     def get_inline_policy_for_permission_set(
-        self, InstanceArn: str, PermissionSetArn: str
+        self, *, InstanceArn: str, PermissionSetArn: str
     ) -> GetInlinePolicyForPermissionSetResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/sso-admin.html#SSOAdmin.Client.get_inline_policy_for_permission_set)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/sso-admin.html#SSOAdmin.Client.get_inline_policy_for_permission_set)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client.html#get_inline_policy_for_permission_set)
         """
 
@@ -261,7 +262,7 @@ class SSOAdminClient:
         Filter: OperationStatusFilterTypeDef = None
     ) -> ListAccountAssignmentCreationStatusResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/sso-admin.html#SSOAdmin.Client.list_account_assignment_creation_status)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/sso-admin.html#SSOAdmin.Client.list_account_assignment_creation_status)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client.html#list_account_assignment_creation_status)
         """
 
@@ -274,7 +275,7 @@ class SSOAdminClient:
         Filter: OperationStatusFilterTypeDef = None
     ) -> ListAccountAssignmentDeletionStatusResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/sso-admin.html#SSOAdmin.Client.list_account_assignment_deletion_status)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/sso-admin.html#SSOAdmin.Client.list_account_assignment_deletion_status)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client.html#list_account_assignment_deletion_status)
         """
 
@@ -288,7 +289,7 @@ class SSOAdminClient:
         NextToken: str = None
     ) -> ListAccountAssignmentsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/sso-admin.html#SSOAdmin.Client.list_account_assignments)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/sso-admin.html#SSOAdmin.Client.list_account_assignments)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client.html#list_account_assignments)
         """
 
@@ -302,15 +303,15 @@ class SSOAdminClient:
         NextToken: str = None
     ) -> ListAccountsForProvisionedPermissionSetResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/sso-admin.html#SSOAdmin.Client.list_accounts_for_provisioned_permission_set)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/sso-admin.html#SSOAdmin.Client.list_accounts_for_provisioned_permission_set)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client.html#list_accounts_for_provisioned_permission_set)
         """
 
     def list_instances(
-        self, MaxResults: int = None, NextToken: str = None
+        self, *, MaxResults: int = None, NextToken: str = None
     ) -> ListInstancesResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/sso-admin.html#SSOAdmin.Client.list_instances)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/sso-admin.html#SSOAdmin.Client.list_instances)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client.html#list_instances)
         """
 
@@ -323,7 +324,7 @@ class SSOAdminClient:
         NextToken: str = None
     ) -> ListManagedPoliciesInPermissionSetResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/sso-admin.html#SSOAdmin.Client.list_managed_policies_in_permission_set)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/sso-admin.html#SSOAdmin.Client.list_managed_policies_in_permission_set)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client.html#list_managed_policies_in_permission_set)
         """
 
@@ -336,7 +337,7 @@ class SSOAdminClient:
         Filter: OperationStatusFilterTypeDef = None
     ) -> ListPermissionSetProvisioningStatusResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/sso-admin.html#SSOAdmin.Client.list_permission_set_provisioning_status)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/sso-admin.html#SSOAdmin.Client.list_permission_set_provisioning_status)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client.html#list_permission_set_provisioning_status)
         """
 
@@ -344,7 +345,7 @@ class SSOAdminClient:
         self, *, InstanceArn: str, NextToken: str = None, MaxResults: int = None
     ) -> ListPermissionSetsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/sso-admin.html#SSOAdmin.Client.list_permission_sets)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/sso-admin.html#SSOAdmin.Client.list_permission_sets)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client.html#list_permission_sets)
         """
 
@@ -358,7 +359,7 @@ class SSOAdminClient:
         NextToken: str = None
     ) -> ListPermissionSetsProvisionedToAccountResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/sso-admin.html#SSOAdmin.Client.list_permission_sets_provisioned_to_account)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/sso-admin.html#SSOAdmin.Client.list_permission_sets_provisioned_to_account)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client.html#list_permission_sets_provisioned_to_account)
         """
 
@@ -366,7 +367,7 @@ class SSOAdminClient:
         self, *, InstanceArn: str, ResourceArn: str, NextToken: str = None
     ) -> ListTagsForResourceResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/sso-admin.html#SSOAdmin.Client.list_tags_for_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/sso-admin.html#SSOAdmin.Client.list_tags_for_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client.html#list_tags_for_resource)
         """
 
@@ -379,7 +380,7 @@ class SSOAdminClient:
         TargetId: str = None
     ) -> ProvisionPermissionSetResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/sso-admin.html#SSOAdmin.Client.provision_permission_set)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/sso-admin.html#SSOAdmin.Client.provision_permission_set)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client.html#provision_permission_set)
         """
 
@@ -387,7 +388,7 @@ class SSOAdminClient:
         self, *, InstanceArn: str, PermissionSetArn: str, InlinePolicy: str
     ) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/sso-admin.html#SSOAdmin.Client.put_inline_policy_to_permission_set)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/sso-admin.html#SSOAdmin.Client.put_inline_policy_to_permission_set)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client.html#put_inline_policy_to_permission_set)
         """
 
@@ -395,7 +396,7 @@ class SSOAdminClient:
         self, *, InstanceArn: str, ResourceArn: str, Tags: List["TagTypeDef"]
     ) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/sso-admin.html#SSOAdmin.Client.tag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/sso-admin.html#SSOAdmin.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client.html#tag_resource)
         """
 
@@ -403,17 +404,18 @@ class SSOAdminClient:
         self, *, InstanceArn: str, ResourceArn: str, TagKeys: List[str]
     ) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/sso-admin.html#SSOAdmin.Client.untag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/sso-admin.html#SSOAdmin.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client.html#untag_resource)
         """
 
     def update_instance_access_control_attribute_configuration(
         self,
+        *,
         InstanceArn: str,
-        InstanceAccessControlAttributeConfiguration: "InstanceAccessControlAttributeConfigurationTypeDef",
+        InstanceAccessControlAttributeConfiguration: "InstanceAccessControlAttributeConfigurationTypeDef"
     ) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/sso-admin.html#SSOAdmin.Client.update_instance_access_control_attribute_configuration)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/sso-admin.html#SSOAdmin.Client.update_instance_access_control_attribute_configuration)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client.html#update_instance_access_control_attribute_configuration)
         """
 
@@ -427,7 +429,7 @@ class SSOAdminClient:
         RelayState: str = None
     ) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/sso-admin.html#SSOAdmin.Client.update_permission_set)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/sso-admin.html#SSOAdmin.Client.update_permission_set)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client.html#update_permission_set)
         """
 
@@ -436,7 +438,7 @@ class SSOAdminClient:
         self, operation_name: Literal["list_account_assignment_creation_status"]
     ) -> ListAccountAssignmentCreationStatusPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/sso-admin.html#SSOAdmin.Paginator.ListAccountAssignmentCreationStatus)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/paginators.html#listaccountassignmentcreationstatuspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/sso-admin.html#SSOAdmin.Paginator.ListAccountAssignmentCreationStatus)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/paginators.html#listaccountassignmentcreationstatuspaginator)
         """
 
     @overload
@@ -444,7 +446,7 @@ class SSOAdminClient:
         self, operation_name: Literal["list_account_assignment_deletion_status"]
     ) -> ListAccountAssignmentDeletionStatusPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/sso-admin.html#SSOAdmin.Paginator.ListAccountAssignmentDeletionStatus)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/paginators.html#listaccountassignmentdeletionstatuspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/sso-admin.html#SSOAdmin.Paginator.ListAccountAssignmentDeletionStatus)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/paginators.html#listaccountassignmentdeletionstatuspaginator)
         """
 
     @overload
@@ -452,7 +454,7 @@ class SSOAdminClient:
         self, operation_name: Literal["list_account_assignments"]
     ) -> ListAccountAssignmentsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/sso-admin.html#SSOAdmin.Paginator.ListAccountAssignments)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/paginators.html#listaccountassignmentspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/sso-admin.html#SSOAdmin.Paginator.ListAccountAssignments)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/paginators.html#listaccountassignmentspaginator)
         """
 
     @overload
@@ -460,13 +462,13 @@ class SSOAdminClient:
         self, operation_name: Literal["list_accounts_for_provisioned_permission_set"]
     ) -> ListAccountsForProvisionedPermissionSetPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/sso-admin.html#SSOAdmin.Paginator.ListAccountsForProvisionedPermissionSet)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/paginators.html#listaccountsforprovisionedpermissionsetpaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/sso-admin.html#SSOAdmin.Paginator.ListAccountsForProvisionedPermissionSet)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/paginators.html#listaccountsforprovisionedpermissionsetpaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_instances"]) -> ListInstancesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/sso-admin.html#SSOAdmin.Paginator.ListInstances)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/paginators.html#listinstancespaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/sso-admin.html#SSOAdmin.Paginator.ListInstances)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/paginators.html#listinstancespaginator)
         """
 
     @overload
@@ -474,7 +476,7 @@ class SSOAdminClient:
         self, operation_name: Literal["list_managed_policies_in_permission_set"]
     ) -> ListManagedPoliciesInPermissionSetPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/sso-admin.html#SSOAdmin.Paginator.ListManagedPoliciesInPermissionSet)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/paginators.html#listmanagedpoliciesinpermissionsetpaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/sso-admin.html#SSOAdmin.Paginator.ListManagedPoliciesInPermissionSet)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/paginators.html#listmanagedpoliciesinpermissionsetpaginator)
         """
 
     @overload
@@ -482,7 +484,7 @@ class SSOAdminClient:
         self, operation_name: Literal["list_permission_set_provisioning_status"]
     ) -> ListPermissionSetProvisioningStatusPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/sso-admin.html#SSOAdmin.Paginator.ListPermissionSetProvisioningStatus)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/paginators.html#listpermissionsetprovisioningstatuspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/sso-admin.html#SSOAdmin.Paginator.ListPermissionSetProvisioningStatus)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/paginators.html#listpermissionsetprovisioningstatuspaginator)
         """
 
     @overload
@@ -490,7 +492,7 @@ class SSOAdminClient:
         self, operation_name: Literal["list_permission_sets"]
     ) -> ListPermissionSetsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/sso-admin.html#SSOAdmin.Paginator.ListPermissionSets)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/paginators.html#listpermissionsetspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/sso-admin.html#SSOAdmin.Paginator.ListPermissionSets)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/paginators.html#listpermissionsetspaginator)
         """
 
     @overload
@@ -498,7 +500,7 @@ class SSOAdminClient:
         self, operation_name: Literal["list_permission_sets_provisioned_to_account"]
     ) -> ListPermissionSetsProvisionedToAccountPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/sso-admin.html#SSOAdmin.Paginator.ListPermissionSetsProvisionedToAccount)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/paginators.html#listpermissionsetsprovisionedtoaccountpaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/sso-admin.html#SSOAdmin.Paginator.ListPermissionSetsProvisionedToAccount)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/paginators.html#listpermissionsetsprovisionedtoaccountpaginator)
         """
 
     @overload
@@ -506,5 +508,5 @@ class SSOAdminClient:
         self, operation_name: Literal["list_tags_for_resource"]
     ) -> ListTagsForResourcePaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.91/reference/services/sso-admin.html#SSOAdmin.Paginator.ListTagsForResource)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/paginators.html#listtagsforresourcepaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/sso-admin.html#SSOAdmin.Paginator.ListTagsForResource)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/paginators.html#listtagsforresourcepaginator)
         """
